﻿//*************************************************}
//                                                 }
//       Program: TIDBartecUHF                    }
//       Programmed with Visual Studio 2008        }
//       Programmed by Sascha Haveloh              }
//       
//                                                 }
//*************************************************}
// Version 1.0 - 29.10.2012  
// Testing UHF Reader
// Import Class..RFIDFeigBartec.cs

using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace TIDBartecUHF
{
    public partial class frmMain : Form
    {
        public frmMain()
        {
            InitializeComponent();
        }

        public RFIDFeig RFID = new RFIDFeig();  // FEIG Class



        public sealed class ControlChars
        {
            public const char Back = '\b';
            public const char Cr = '\r';
            public const string CrLf = "\r\n";
            public const char FormFeed = '\f';
            public const char Lf = '\n';
            public const string NewLine = "\r\n";
            public const char NullChar = '\0';
            public const char Quote = '"';
            public const char Tab = '\t';
            public const char VerticalTab = '\v';
        }


        private void ButtonActive(int active)
        {
            for (int i = 0; i < this.Controls.Count; i++)
            {
                if (this.Controls[i] is Button)
                {
                    this.Controls[i].Enabled = (active == 1);
                }
            }
        }

        private void InfoAdd(string value)
        {
            if (value == null) { return; }
            InfoBox.Items.Add(value);
            InfoBox.SelectedIndex = InfoBox.Items.Count - 1;
        }

        private void ExitItem_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void frmMain_Closing(object sender, CancelEventArgs e)
        {
            e.Cancel = MessageBox.Show("Exit program ?", this.Text, MessageBoxButtons.YesNo, MessageBoxIcon.Question, MessageBoxDefaultButton.Button1) == DialogResult.No;     
        }

        private void InfoItem_Click(object sender, EventArgs e)
        {
            MessageBox.Show("TECTUS Transponder Technology GmbH" +
               "www.tec-tus.de" + ControlChars.CrLf  +
               "(c)2012 / (30.10.2012)..C" + ControlChars.CrLf +
                "TIDBartecUHF V1.0");                                 
        }

        private void frmMain_Load(object sender, EventArgs e)
        {
            RFID.GetReaderText += new RFIDFeig.GetReaderTextEventHandler(RFID_GetReaderText);
            ButtonActive(0); 
        }

        private void RFID_GetReaderText(string Info_Text)
        {
            InfoAdd(Info_Text);
        }


        private void cbConnectUHF_CheckStateChanged(object sender, EventArgs e)
        {
            if (cbConnectUHF.Checked)
            {
                RFID.Initialize("1");  // PDA Comport 1
            }
            else
            {
                RFID.ReaderUnload();
            }
            if (RFID.IsActive)
            {
                InfoAdd("Reader ON");
                ButtonActive(1); 
            }
            else
            {
                InfoAdd("Reader OFF");
                cbConnectUHF.Checked = false;
                RFID.ReaderUnload();
                ButtonActive(0); 
            }
        }

        private void frmMain_Closed(object sender, EventArgs e)
        {
            RFID.ReaderUnload();
        }

        private void btInfo_Click(object sender, EventArgs e)
        {
            InfoAdd("FEISC_0x65_SoftVersion()");
            if (RFID.GetReaderInfo(0))
            {
                InfoAdd(RFID.InfoReader[0]);
                InfoAdd(RFID.InfoReader[1]);
                InfoAdd(RFID.InfoReader[2]);
                InfoAdd(RFID.InfoReader[3]);
            }
            ButtonActive(1);
        }

        private void btGetTAGNumber_Click(object sender, EventArgs e)
        {
            InfoAdd("FEISC_0xB0_ISOCmd");
            if (RFID.GetUID())
            {
                InfoAdd(RFID.UIDNr);
                InfoAdd(RFID.TagTyp);
            }
            else
            {
                InfoAdd("No UID found");     
            }
        }

        private void btGetRFPower_Click(object sender, EventArgs e)
        {
            /*0 - Full Power
            1 - Medium Power
            2 - Low Power*/

            if (RFID.GetConfig_RFPower() == 0)
            {
                cbRFPower.SelectedIndex = RFID.RFPower;
                InfoAdd("Get RFPower = OK");
                switch (RFID.RFPower)
                {
                    case 0:
                        lbRFPower.Text = "0 - Full Power";
                        break; 
                    case 1:
                        lbRFPower.Text = "2 - Medium Power";
                        break; 
                    case 2:
                        lbRFPower.Text = "2 - Low Power";
                        break; 
                }
            }
            else
            {
                InfoAdd("Get RFPower = Error");
            }
        }

        private void btSetRF_Click(object sender, EventArgs e)
        {
            RFID.RFPower = cbRFPower.SelectedIndex;
            if (RFID.SetConfig_RFPower() == 0)
            {
                InfoAdd("Set RFPower = OK");
            }
            else
            {
                InfoAdd("Set RFPower = Error");
            }
  
        }

        private void btRFOn_Click(object sender, EventArgs e)
        {
            if (RFID.SetRF_ON_OFF(1) == 0)  // i don't now if it works
            {
                InfoAdd("RF_ON = OK");
            }
            else
            {
                InfoAdd("RF_ON = Error");
            }
        }

        private void btRFOff_Click(object sender, EventArgs e)
        {
            if (RFID.SetRF_ON_OFF(0) == 0)
            {
                InfoAdd("RF_OFF = OK");
            }
            else
            {
                InfoAdd("RF_OFF = Error");
            }
        }

        private void btReadBlock_Click(object sender, EventArgs e)
        {
            InfoAdd("Search UID");
            if (RFID.GetUID())
            {
                InfoAdd(RFID.UIDNr);
                InfoAdd("Read Block");
                if (RFID.UIDNr.Length == 24)  // UHF TAGS
                {
                    if (RFID.ReadTagBlock24((byte)spBlock.Value, (byte)spBlockLength.Value, 1))  // 1 = HEX 0 =  ASCII
                    {
                        InfoAdd(RFID.BlockDataHex);
                    }
                    else
                    {
                        InfoAdd("No data found.");
                    }
                }
                else // HF TAGS
                {
                    if (RFID.ReadTagBlock((byte)spBlock.Value, (byte)spBlockLength.Value, 1))  // 1 = HEX 0 =  ASCII
                    {
                        InfoAdd(RFID.BlockDataHex);
                    }
                    else
                    {
                        InfoAdd("No data found.");
                    }
                }
            }
            else
            {
                InfoAdd("No UID found");
            }
        }
    }
}